bin Package
===========

:mod:`bin` Package
------------------

.. automodule:: camelot.bin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`camelot_admin` Module
---------------------------

.. automodule:: camelot.bin.camelot_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`camelot_manage` Module
----------------------------

.. automodule:: camelot.bin.camelot_manage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`meta` Module
------------------

.. automodule:: camelot.bin.meta
    :members:
    :undoc-members:
    :show-inheritance:

